From 3b57b1315c478129d03610bbc6e461619aae7c21 Mon Sep 17 00:00:00 2001
From: Ariver <shanghai3168@gmail.com>
Date: Wed, 03 Jun 2026 21:54:06 +0800
Subject: [PATCH] Localize macOS app display name

---
 privatevoice.src/scripts/build-release-macos.sh |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)

diff --git a/privatevoice.src/scripts/build-release-macos.sh b/privatevoice.src/scripts/build-release-macos.sh
index 3f33265..6968535 100755
--- a/privatevoice.src/scripts/build-release-macos.sh
+++ b/privatevoice.src/scripts/build-release-macos.sh
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
 # build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Input
 #
 # Prerequisites (one-time):
 #   1. Install Developer ID certificate in Keychain
@@ -19,7 +19,7 @@
 IDENTITY="Developer ID Application: Ningbo Zhuozhi Innovation Network Technology Co., Ltd. (3HY4G7M2AL)"
 KEYCHAIN_PROFILE="privatevoice"
 
-APP_NAME="PrivateVoice Input"
+APP_NAME="PrivateVoice Dictation"
 BUNDLE_ID="com.privatevoice.input"
 
 SCRIPT_DIR="$(cd "$(dirname "$0")" && pwd)"
@@ -116,6 +116,8 @@
 cp "$BUILD_DIR/${APP_NAME}"              "$APP_BUNDLE/Contents/MacOS/${APP_NAME}"
 cp "$PROJECT_DIR/build/darwin/icon.icns" \
                                          "$APP_BUNDLE/Contents/Resources/icon.icns"
+find "$PROJECT_DIR/build/darwin" -maxdepth 1 -type d -name "*.lproj" \
+  -exec cp -R {} "$APP_BUNDLE/Contents/Resources/" \;
 
 # Copy dylibs
 cp "$SHERPA_LIB_DIR/libsherpa-onnx-c-api.dylib"   "$APP_BUNDLE/Contents/Frameworks/"
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
-# build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Input
+# build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Dictation
 #
 # Prerequisites (one-time):

--
Gitblit v1.9.3